@@ -252,8 +252,7 @@ class UWC_Content {
 	  $this->data->select_content_next_by_path_lang_and_status($this->path,$this->lang,$this->get_user_status(),$this->get_order());
 	}
 	if ($row=$this->data->query_select_fetch_row()) {
-	  $this->next=array("path"=>$row["content_path"],"title"=>$row["content_
-title"]);
+	  $this->next=array("path"=>$row["content_path"],"title"=>$row["content_title"]);
 	}
 	$this->data->query_select_free();
       }
