@@ -60,8 +60,12 @@ function uwc_format_text_to_html($str) {
   return uwc_format_htmlfriendly(htmlentities($str));
 }
 
+function uwc_format_html_to_xul($str) {
+  return htmlspecialchars(html_entity_decode($str));
+}
+
 function uwc_format_text_to_xul($str) {
-  return htmlspecialchars(html_entity_decode(uwc_format_text_to_html($str)));
+  return uwc_format_html_to_xul(uwc_format_text_to_html($str));
 }
 
 function uwc_format_text_to_html_attribute($str) {
