@@ -114,11 +114,13 @@ $this->messages=array
    "filename_width_height_size"=>"%s - %d&nbsp;x&nbsp;%d - %so",
    "current_image"=>"Image actuelle",
    "allinone_status"=>"N'afficher que les documents dans cet &eacute;tat",
+   "allinone_intro"=>"Texte d'introduction",
    "allinone_max_size"=>"Taille max des images (en pixels)",
    "gallery_title"=>"Diaporama XUL",
    "gallery_prev"=>"Image prcdente",
    "gallery_next"=>"Image suivante",
    "gallery_empty"=>"Aucune image dans ce diaporama",
+   "google_search"=>"Recherche Google",
 
    ""=>""
    );
