@@ -360,14 +360,18 @@ class UWC_Page {
     return $status;
   }
 
-  function get_allinone_subtitle() {
+  function get_allinone_default_intro() {
     if ($this->context->is_home()) {
-      $subtitle=$this->translate2("all_in_one_site",$this->content->get_title(),$this->today());
+      $intro=$this->translate2("all_in_one_site",$this->content->get_title(),$this->today());
     } else {
-      $subtitle=$this->translate2("all_in_one_subsite",$this->content->get_title(),$this->today());
+      $intro=$this->translate2("all_in_one_subsite",$this->content->get_title(),$this->today());
     }
 
-    return $subtitle;
+    return $intro;
+  }
+
+  function get_allinone_intro() {
+    return uwc_format_text_to_html(uwc_format_unescape_gpc($this->request->get_value("intro")));
   }
 
   function get_tree() {
@@ -458,6 +462,19 @@ class UWC_Page {
     return $this->conf->htprefix;
   }
 
+  function get_domain_name() {
+    /*
+     * Obviously this domain name computing could be put
+     * in the Config object itself. However we only need
+     * domain name for Google searches, so it's useless
+     * to bother moving it. Besides, putting this code here
+     * will cause it not to be executed when page is cached.
+     */
+    preg_match("/^((http|https):\/\/)?([^\/\:]+)/i",$this->conf->siteurl, $matches);
+    $domain_name = $matches[3];
+    return $domain_name;
+  }
+
   function get_absolute_url() {
     return $this->conf->siteurl.$this->make_url($this->get_path(),array("login"=>"","password"=>""));
   }
@@ -938,6 +955,10 @@ class UWC_Page {
     return $this->content->get_prev() ? true : false;
   }
 
+  function need_google() {
+    return $this->content->get_status()==0;
+  }
+
   function include_external() {
     uwc_external_include($this);
   }
