@@ -2,7 +2,7 @@
 
 <div class="default">
 <p>
-<? echo $this->get_allinone_subtitle(); ?>
+<? echo $this->get_allinone_intro(); ?>
 </p>
 </div>
 
