@@ -21,6 +21,8 @@
    } ?>
 </select>
 </dd>
+<dt><? echo $this->translate("allinone_intro"); ?></dt>
+<dd><textarea cols="<? echo $this->get_input_width1(); ?>" rows="<? echo $this->get_input_height1(); ?>" name="intro"><? echo $this->get_allinone_default_intro(); ?></textarea></dd>
 <dt><? echo $this->translate("allinone_max_size"); ?></dt>
 <dd><input type="edit" name="max_size" size="5" maxlength="5" value="<? echo UWC_CONTEXT_ALLINONE_MAX_SIZE; ?>" class="edit" /></dd>
 </dl>
