@@ -103,6 +103,20 @@ if (count($langs)>0) {
     </div>
     <? } ?>
 
+    <? if ($this->need_google()) {?>
+    <div id="google">
+       <form action="http://www.google.fr/search" method="get" id="google_form">
+       <p>
+	    <input type="hidden" id="google_ie" name="ie" value="latin1" />
+	    <input type="hidden" id="google_as_dt" name="as_dt" value="i" />
+	    <input type="hidden" id="google_as_sitesearch" name="as_sitesearch" value="<? echo $this->get_domain_name(); ?>" />
+	    <input type="text" size="16" maxlength="192" id="google_q" name="q" />
+	    <input type="submit" id="google_search" name="search" value="<? echo $this->translate("google_search"); ?>" />
+       </p>
+        </form>
+    </div> 
+    <? } ?>
+
     </div>
 
     </div>
