@@ -2,7 +2,7 @@
 
 <div class="image">
 <div>
-<a href="<? echo $this->get_image_full_url(); ?>"><img src="<? echo $this->get_image_full_url(); ?>" width="<? echo $this->get_image_full_w(); ?>" height="<? echo $this->get_image_full_h(); ?>" alt="<? echo $this->get_legend_alt(); ?>" class="msiehackimage" /></a>
+<a href="<? echo $this->get_image_full_url(); ?>"><img src="<? echo $this->get_image_full_url(); ?>" width="<? echo $this->get_image_fullscaled_w(); ?>" height="<? echo $this->get_image_fullscaled_h(); ?>" alt="<? echo $this->get_legend_alt(); ?>" class="msiehackimage" /></a>
 </div>
 <div>
 <? echo $this->translate4("filename_width_height_size",$this->get_image_filename(),$this->get_image_full_w(),$this->get_image_full_h(),$this->get_image_size()); ?>
